@@ -29,6 +29,7 @@ sub new {
 		'+columns' => $$req{'+columns'},
 		primary_keys => $$req{primary_keys},
 	 	ai_primary_keys => $$req{ai_primary_keys},
+		defaults => $$req{defaults},
 
 	 };
 	 $self->{log} = Log::Log4perl->get_logger("Gtk2::Ex::DbLinker::RdbDataManager");
@@ -119,8 +120,16 @@ sub set_field{
 sub get_field{
 	my ($self, $id) = @_;
 	my $pos =  $self->{row}->{pos};
-	my $row = $self->{data}[$pos];
-	
+	my $last =  $self->row_count;
+	$self->{log}->debug("get_field: pos ", $pos, " last : ", $last);
+	my $row ;
+	if ($pos < $last) {
+		$row = $self->{data}[$pos];
+	} elsif ($pos == $last) {
+		$row = $self->{new_row};
+	} else {
+		$self->{log}->debug("current pos outside row limits");
+	}
 	my $rel = $self->{fieldsRel}->{$id};
 	$rel = ( $rel ? $rel : "");
 	my $key = $rel . $id;
@@ -161,12 +170,14 @@ sub save{
 }
 sub new_row {
 	my ($self ) = @_;
-	#return if ($self->{new_row});
+	$self->{log}->debug("new_row");
 	my $class =  $self->{class};
-	my $row = $class->new;
+	my @def = (%{$self->{defaults}}) if ($self->{defaults});
+	my $row = $class->new(@def);
 	$self->{new_row} = $row;
+	#push @{$self->{data}}, $row;
 	$self->{row}->{pos} = $self->{row}->{last_row} + 1;
-	#$self->{log}->debug("new_row: " . Dumper($row));
+	$self->{log}->debug("new_row: pos ", $self->{row}->{pos} );
 	
 }
 
@@ -368,6 +379,10 @@ sub _move {
 
 }
 
+sub get_class {
+	shift->{class};
+}
+
 1;
 
 __END__
@@ -380,7 +395,7 @@ Gtk2::Ex::DbLinker::RdbDataManager - a module that get data from a database usin
 
 =head1 VERSION
 
-See Version in L<Gtk2::Ex::DbLinker>
+See Version in L<Gtk2::Ex::DbLinker::DbTools>
 
 =head1 SYNOPSIS
 
@@ -530,7 +545,7 @@ Return an array of autoincremented primary key(s) defined by the the 'serial' co
 Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
-L<http://sourceforge.net/projects/gtk2-ex-dblinker/>.
+L<http://sourceforge.net/projects/gtk2-ex-dblinker-dbtools/>.
 
 =head1 AUTHOR
 
